//
//  Hour19_DetailViewController.m
//  Estimator
//
//  Created by Jesse Feiler on 8/9/11.
//  Copyright (c) 2011 another. All rights reserved.
//

#import "Hour19_DetailViewController.h"

@interface Hour19_DetailViewController ()

@property (nonatomic, retain, readonly) NSNumberFormatter *numberFormatter;

@property (strong, nonatomic) UIPopoverController *popoverController;

- (void)configureView;

@end

@implementation Hour19_DetailViewController

@synthesize estimatorTableView = _estimatorTableView;
@synthesize detailItem = _detailItem;
@synthesize popoverController = _myPopoverController;
@synthesize numberFormatter;

- (NSNumberFormatter *)numberFormatter
{
    if (numberFormatter == nil)
    {
        numberFormatter = [[NSNumberFormatter alloc] init];
        [numberFormatter setNumberStyle:NSNumberFormatterPercentStyle];
        [numberFormatter setMaximumFractionDigits:1];
    }
    return numberFormatter;
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    return self;
}

#pragma mark - Managing the detail item

- (void)setDetailItem:(id)newDetailItem
{
    if (_detailItem != newDetailItem) {
        
        if (_detailItem) {
            [self save];
        }
        
        _detailItem = newDetailItem;
        
        // Update the view.
        [self configureView];
    }

    self.title = [self.detailItem valueForKey:@"name"];
    
    if (self.popoverController != nil) {
        [self.popoverController dismissPopoverAnimated:YES];
    }        
}

- (void)configureView
{
    // Update the user interface for the detail item.
    [self.estimatorTableView reloadData];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - Object lifecycle

- (void) save {
    NSError *error;
    if (![self.detailItem.managedObjectContext save:&error]) {
        // Update to handle the error appropriately.
        NSLog(@"Unresolved error %@, %@", error, [error userInfo]);
        exit(-1);  // Fail
    }    
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    [self configureView];
}

- (void)viewDidUnload
{
    [self setEstimatorTableView:nil];
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
	[super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) {
        return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
    } else {
        return YES;
    }
}

#pragma mark - UITableViewDataSource Protocol

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return 7;
}

// Customize the appearance of table view cells.
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"CellStyle2";
    
    id tester = self.detailItem;
    NSManagedObject *nsmTest;
    nsmTest = (NSManagedObject *)tester;
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue2 reuseIdentifier:CellIdentifier];
    }
    
    // Configure the cell for each row
    switch (indexPath.row)
    {
        case 0:
        {
            cell.textLabel.text = @"Name";
			cell.detailTextLabel.text = [self.detailItem valueForKey:@"name"];
            break;
        }
            
        case 1:
        {
            cell.textLabel.text = @"Email";
            cell.detailTextLabel.text = [self.detailItem valueForKey:@"email"];
            break;
        }
            
        case 2:
        {
            cell.textLabel.text = @"Address";
            cell.detailTextLabel.text = [self.detailItem valueForKey:@"address"];
            break;
        }
            
        case 3:
        {
            cell.textLabel.text = @"City";
            cell.detailTextLabel.text = [self.detailItem valueForKey:@"city"];
            break;
        }
          
        case 4:
        {
            cell.textLabel.text = @"State/Province";
            cell.detailTextLabel.text = [self.detailItem valueForKey:@"state"];
            break;
        }
            
        case 5:
        {
            cell.textLabel.text = @"Postal Code";
            cell.detailTextLabel.text = [self.detailItem valueForKey:@"zip"];
            break;
        }
                        
        case 6:
        {
			cell.textLabel.text = @"Customer Since";
			NSNumber *customerSince = (NSNumber*)[self.detailItem valueForKey:@"customerSince"];
			cell.detailTextLabel.text = [customerSince stringValue];
			break;
        }
		

    } // end switch
    
    return cell;
}

#pragma mark - Split view

- (void)splitViewController:(UISplitViewController *)splitController willHideViewController:(UIViewController *)viewController withBarButtonItem:(UIBarButtonItem *)barButtonItem forPopoverController:(UIPopoverController *)popoverController
{
    barButtonItem.title = NSLocalizedString(@"Master", @"Master");
    [self.navigationItem setLeftBarButtonItem:barButtonItem animated:YES];
    self.popoverController = popoverController;
}

- (void)splitViewController:(UISplitViewController *)splitController willShowViewController:(UIViewController *)viewController invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem
{
    // Called when the view is shown again in the split view, invalidating the button and popover controller.
    [self.navigationItem setLeftBarButtonItem:nil animated:YES];
    self.popoverController = nil;
}

@end
